bayespy.inference.vmp.nodes.stochastic.Stochastic.observe
=========================================================

.. currentmodule:: bayespy.inference.vmp.nodes.stochastic

.. automethod:: Stochastic.observe